K-Nearest Neighbour {#tutorial_py_knn_index}
===================

-   @subpage tutorial_py_knn_understanding

    Get a basic understanding of what kNN is

-   @subpage tutorial_py_knn_opencv

    Now let's use kNN in OpenCV for digit recognition OCR
